
data { 
	int<lower=1> Nvisit; // Number of choice situations
	int<lower=1> Nprov; // Number of alternatives 
	int<lower=1> Nchoice; // Total number of choices
	int<lower=1,upper=Nchoice> Ns; // Number of individuals who know prices
	//int<lower=1> Nindiv; // Number of individuals
	int<lower=1> Cx; // Number of demand variables other than price
	
	int<lower=1,upper=Nprov> provid[Nchoice]; // Option/Firm ID
	int<lower=1,upper=Nchoice> visitid[Nchoice]; // Visit ID
	int<lower=1,upper=Nprov> Vprov[Nvisit]; // Num of options/firms in each choice set
	int<lower=1,upper=Nchoice> Pcs[Nvisit]; // Starting position of each choice situation
	
	vector[Nvisit] h; // search indicator
	vector[Nchoice] price; // Price of each choice
	matrix[Nchoice,Cx] Xd; // Demand variables other than price
	vector[Nchoice] mean_price; // Mean of prices in choice set
	vector[Nchoice] std_price; // Standard deviation of prices in choice set
	
	int<lower=1,upper=Nprov> y[Nvisit]; // choice index
}

parameters {
	real<lower=-10,upper=10> param_price_mu;
	vector<lower=-10,upper=10>[Cx] param_dchars;
	real<lower=0,upper=50> param_snoise_sigma;
	vector<lower=0,upper=50>[Nprov-1] param_provid_free; // Option/Firm FEs (without normalized option)
	vector[Nchoice] snoise_raw; // Price signal noise
}

model {
	vector[Nprov] param_provid;
	vector[Nchoice] mean_posterior;
	vector[Nchoice] V_ns;
	//vector[Nchoice] V_max;
	vector[Nchoice] V_s;
	
	vector[Nchoice] weight;
	
	// Provider FEs (normalize outside option)
	param_provid[1] <- 0;
	for (i in 2:Nprov) param_provid[i] <- param_provid_free[i-1];
	
	// When individuals don't know prices
	weight <- (std_price .* std_price) ./ (param_snoise_sigma * param_snoise_sigma + std_price .* std_price);
	mean_posterior <- weight .* (price + param_snoise_sigma * snoise_raw) + (1 - weight) .* mean_price;
	V_ns <- param_provid[provid] + mean_posterior * param_price_mu + Xd * param_dchars;
	
	// Rescale due to underflow/overflow issues
	//for (n in 1:Nvisit) V_max[n] <- max(segment(V_ns,Pcs[n],Vprov[n]));
	//V_ns <- V_ns - V_max[visitid];
	
	// When individuals know prices
	V_s <- param_provid[provid] + price * param_price_mu + Xd * param_dchars;
	
	// Rescale bc of potential overflow/underflow
	//for (n in 1:Nvisit) V_max[n] <- max(segment(V_s,Pcs[n],Vprov[n]));
	//V_s <- V_s - V_max[visitid];
	
	// Signal noise (normalized to standard normal)
	snoise_raw ~ normal(0,1);
	
	// Log likelihood
	for (n in 1:Nvisit) increment_log_prob(log_mix(h[n],
			categorical_logit_log(y[n],segment(V_s,Pcs[n],Vprov[n])),
			categorical_logit_log(y[n],segment(V_ns,Pcs[n],Vprov[n]))
		));
}

