clear
cd('/Users/PriceTransparency/code')

% Add path to stan
addpath('/stan/cmdstan-2.9.0')
addpath('/stan/MatlabProcessManager-master')
addpath('/stan/MatlabStan-2.7.0.0')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load Simulated Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load('data.mat')


% Sort
sortrows(data,'h');

% Constants
Nvisit=size(unique(data.visitid),1);
Nprov=size(unique(data.provid),1);
Nchoice = size(data,1);
Ns = sum(data.h);

% Number of providers in choice set (Nvisit x 1)
Vprov = accumarray(data.visitid,data.provid,[],@(x) size(unique(x),1));

% Position of visit (Nvisit x 1)
Pcs_tmp = cumsum(Vprov) + 1;
Pcs = ones(Nvisit,1);
Pcs(2:end) = Pcs_tmp(1:(end-1));

% Position of chosen option within the visit
prov_id_within = zeros(Nchoice,1);
for (g = 1:Nvisit) prov_id_within(data.visitid==g) = grp2idx(num2str(data.provid(data.visitid==g))); end
y = prov_id_within(logical(data.choice));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data_struct = struct('Nvisit',Nvisit,'Nprov',Nprov, ...
        'Nchoice', Nchoice,'Ns',Ns,'Cx',2,'Vprov',Vprov,'Pcs',Pcs, ...
        'y',y,'provid',data.provid,'visitid',data.visitid,'h',data.h(data.choice==1),'price',data.price,'Xd',[data.x1, data.x2], ...
        'mean_price',data.mean_price,'std_price',data.std_price);

delete('temp.data.R','temp.init.R','mcmcmodel','mcmcmodel.hpp');
fit1 = stan('file','mcmcmodel.stan','data',data_struct,'iter',2000,'file_overwrite',true,'verbose',true,'chains',4,'refresh',10);

return;

% Load Sample estimates
all_chains = array2table([]);
files = {'output-1.csv', 'output-2.csv','output-3.csv', 'output-4.csv'};
files = {'samp_output_small1.csv', 'samp_output_small2.csv','samp_output_small3.csv', 'samp_output_small4.csv'};
for (chaini = 1:size(files,2))
    filename = files(chaini);
    A = importdata(char(filename),',',42);
    header = strrep(strsplit(char(A.textdata(38)),','),'.','_');
    T = array2table(A.data,'VariableNames',header);
    all_chains = vertcat(all_chains,T);
end

samp_est_mean = table2dataset(varfun(@mean,all_chains));

fprintf('param_price_mu: %5.3f 	\n',samp_est_mean.mean_param_price_mu)
fprintf('param_dchars_1: %5.3f 	\n',samp_est_mean.mean_param_dchars_1)
fprintf('param_dchars_2: %5.3f 	\n',samp_est_mean.mean_param_dchars_2)
fprintf('param_provid_2: %5.3f 	\n',samp_est_mean.mean_param_provid_free_1)
fprintf('param_provid_3: %5.3f 	\n',samp_est_mean.mean_param_provid_free_2)
fprintf('param_snoise_sigma: %5.3f  \n',samp_est_mean.mean_param_snoise_sigma)


samp_est_std = table2dataset(varfun(@std,all_chains));
fprintf('param_price_mu: %5.3f 	\n',samp_est_std.std_param_price_mu)
fprintf('param_dchars_1: %5.3f 	\n',samp_est_std.std_param_dchars_1)
fprintf('param_dchars_2: %5.3f 	\n',samp_est_std.std_param_dchars_2)
fprintf('param_provid_2: %5.3f 	\n',samp_est_std.std_param_provid_free_1)
fprintf('param_provid_3: %5.3f 	\n',samp_est_std.std_param_provid_free_2)
fprintf('param_snoise_sigma: %5.3f  \n',samp_est_std.std_param_snoise_sigma)

